# coding: utf-8

# flake8: noqa

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from orcid_api_v3.api.development_member_api_v3_0_api import DevelopmentMemberAPIV30Api
from orcid_api_v3.api.development_member_api_v3_0_rc1_api import DevelopmentMemberAPIV30Rc1Api
from orcid_api_v3.api.development_member_api_v3_0_rc2_api import DevelopmentMemberAPIV30Rc2Api
from orcid_api_v3.api.member_api_v2_0_api import MemberAPIV20Api
from orcid_api_v3.api.member_api_v2_1_api import MemberAPIV21Api
# import ApiClient
from orcid_api_v3.api_client import ApiClient
from orcid_api_v3.configuration import Configuration
# import models into sdk package
from orcid_api_v3.models.activities_summary_v20 import ActivitiesSummaryV20
from orcid_api_v3.models.activities_summary_v30 import ActivitiesSummaryV30
from orcid_api_v3.models.activities_summary_v30_rc1 import ActivitiesSummaryV30Rc1
from orcid_api_v3.models.activities_summary_v30_rc2 import ActivitiesSummaryV30Rc2
from orcid_api_v3.models.address_v20 import AddressV20
from orcid_api_v3.models.address_v30 import AddressV30
from orcid_api_v3.models.address_v30_rc1 import AddressV30Rc1
from orcid_api_v3.models.address_v30_rc2 import AddressV30Rc2
from orcid_api_v3.models.addresses_v20 import AddressesV20
from orcid_api_v3.models.addresses_v30 import AddressesV30
from orcid_api_v3.models.addresses_v30_rc1 import AddressesV30Rc1
from orcid_api_v3.models.addresses_v30_rc2 import AddressesV30Rc2
from orcid_api_v3.models.affiliation_group_v30 import AffiliationGroupV30
from orcid_api_v3.models.affiliation_group_v30_distinction_summary_v30 import AffiliationGroupV30DistinctionSummaryV30
from orcid_api_v3.models.affiliation_group_v30_education_summary_v30 import AffiliationGroupV30EducationSummaryV30
from orcid_api_v3.models.affiliation_group_v30_employment_summary_v30 import AffiliationGroupV30EmploymentSummaryV30
from orcid_api_v3.models.affiliation_group_v30_invited_position_summary_v30 import AffiliationGroupV30InvitedPositionSummaryV30
from orcid_api_v3.models.affiliation_group_v30_membership_summary_v30 import AffiliationGroupV30MembershipSummaryV30
from orcid_api_v3.models.affiliation_group_v30_qualification_summary_v30 import AffiliationGroupV30QualificationSummaryV30
from orcid_api_v3.models.affiliation_group_v30_rc1 import AffiliationGroupV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_distinction_summary_v30_rc1 import AffiliationGroupV30Rc1DistinctionSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_education_summary_v30_rc1 import AffiliationGroupV30Rc1EducationSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_employment_summary_v30_rc1 import AffiliationGroupV30Rc1EmploymentSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_invited_position_summary_v30_rc1 import AffiliationGroupV30Rc1InvitedPositionSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_membership_summary_v30_rc1 import AffiliationGroupV30Rc1MembershipSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_qualification_summary_v30_rc1 import AffiliationGroupV30Rc1QualificationSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_service_summary_v30_rc1 import AffiliationGroupV30Rc1ServiceSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc2 import AffiliationGroupV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_distinction_summary_v30_rc2 import AffiliationGroupV30Rc2DistinctionSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_education_summary_v30_rc2 import AffiliationGroupV30Rc2EducationSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_employment_summary_v30_rc2 import AffiliationGroupV30Rc2EmploymentSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_invited_position_summary_v30_rc2 import AffiliationGroupV30Rc2InvitedPositionSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_membership_summary_v30_rc2 import AffiliationGroupV30Rc2MembershipSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_qualification_summary_v30_rc2 import AffiliationGroupV30Rc2QualificationSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_service_summary_v30_rc2 import AffiliationGroupV30Rc2ServiceSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_service_summary_v30 import AffiliationGroupV30ServiceSummaryV30
from orcid_api_v3.models.affiliation_summary_v30 import AffiliationSummaryV30
from orcid_api_v3.models.affiliation_summary_v30_rc1 import AffiliationSummaryV30Rc1
from orcid_api_v3.models.affiliation_summary_v30_rc2 import AffiliationSummaryV30Rc2
from orcid_api_v3.models.amount_v20 import AmountV20
from orcid_api_v3.models.amount_v30 import AmountV30
from orcid_api_v3.models.amount_v30_rc1 import AmountV30Rc1
from orcid_api_v3.models.amount_v30_rc2 import AmountV30Rc2
from orcid_api_v3.models.authorization_url_v20 import AuthorizationUrlV20
from orcid_api_v3.models.authorization_url_v30 import AuthorizationUrlV30
from orcid_api_v3.models.authorization_url_v30_rc1 import AuthorizationUrlV30Rc1
from orcid_api_v3.models.authorization_url_v30_rc2 import AuthorizationUrlV30Rc2
from orcid_api_v3.models.biography_v20 import BiographyV20
from orcid_api_v3.models.biography_v30 import BiographyV30
from orcid_api_v3.models.biography_v30_rc1 import BiographyV30Rc1
from orcid_api_v3.models.biography_v30_rc2 import BiographyV30Rc2
from orcid_api_v3.models.bulk_element import BulkElement
from orcid_api_v3.models.citation import Citation
from orcid_api_v3.models.client_summary import ClientSummary
from orcid_api_v3.models.completion_date_v20 import CompletionDateV20
from orcid_api_v3.models.completion_date_v30 import CompletionDateV30
from orcid_api_v3.models.completion_date_v30_rc1 import CompletionDateV30Rc1
from orcid_api_v3.models.completion_date_v30_rc2 import CompletionDateV30Rc2
from orcid_api_v3.models.contributor_attributes_v30 import ContributorAttributesV30
from orcid_api_v3.models.contributor_attributes_v30_rc1 import ContributorAttributesV30Rc1
from orcid_api_v3.models.contributor_attributes_v30_rc2 import ContributorAttributesV30Rc2
from orcid_api_v3.models.contributor_email_v20 import ContributorEmailV20
from orcid_api_v3.models.contributor_email_v30 import ContributorEmailV30
from orcid_api_v3.models.contributor_email_v30_rc1 import ContributorEmailV30Rc1
from orcid_api_v3.models.contributor_email_v30_rc2 import ContributorEmailV30Rc2
from orcid_api_v3.models.contributor_orcid_v20 import ContributorOrcidV20
from orcid_api_v3.models.contributor_orcid_v30 import ContributorOrcidV30
from orcid_api_v3.models.contributor_orcid_v30_rc1 import ContributorOrcidV30Rc1
from orcid_api_v3.models.contributor_orcid_v30_rc2 import ContributorOrcidV30Rc2
from orcid_api_v3.models.contributor_v20 import ContributorV20
from orcid_api_v3.models.contributor_v30 import ContributorV30
from orcid_api_v3.models.contributor_v30_rc1 import ContributorV30Rc1
from orcid_api_v3.models.contributor_v30_rc2 import ContributorV30Rc2
from orcid_api_v3.models.country_v20 import CountryV20
from orcid_api_v3.models.country_v30 import CountryV30
from orcid_api_v3.models.country_v30_rc1 import CountryV30Rc1
from orcid_api_v3.models.country_v30_rc2 import CountryV30Rc2
from orcid_api_v3.models.created_date_v20 import CreatedDateV20
from orcid_api_v3.models.created_date_v30 import CreatedDateV30
from orcid_api_v3.models.created_date_v30_rc1 import CreatedDateV30Rc1
from orcid_api_v3.models.created_date_v30_rc2 import CreatedDateV30Rc2
from orcid_api_v3.models.credit_name_v20 import CreditNameV20
from orcid_api_v3.models.credit_name_v30 import CreditNameV30
from orcid_api_v3.models.credit_name_v30_rc1 import CreditNameV30Rc1
from orcid_api_v3.models.credit_name_v30_rc2 import CreditNameV30Rc2
from orcid_api_v3.models.currency import Currency
from orcid_api_v3.models.day_v20 import DayV20
from orcid_api_v3.models.day_v30 import DayV30
from orcid_api_v3.models.day_v30_rc1 import DayV30Rc1
from orcid_api_v3.models.day_v30_rc2 import DayV30Rc2
from orcid_api_v3.models.deactivation_date_v20 import DeactivationDateV20
from orcid_api_v3.models.deactivation_date_v30 import DeactivationDateV30
from orcid_api_v3.models.deactivation_date_v30_rc1 import DeactivationDateV30Rc1
from orcid_api_v3.models.deactivation_date_v30_rc2 import DeactivationDateV30Rc2
from orcid_api_v3.models.disambiguated_organization_v20 import DisambiguatedOrganizationV20
from orcid_api_v3.models.disambiguated_organization_v30 import DisambiguatedOrganizationV30
from orcid_api_v3.models.disambiguated_organization_v30_rc1 import DisambiguatedOrganizationV30Rc1
from orcid_api_v3.models.disambiguated_organization_v30_rc2 import DisambiguatedOrganizationV30Rc2
from orcid_api_v3.models.distinction_summary_v30 import DistinctionSummaryV30
from orcid_api_v3.models.distinction_summary_v30_rc1 import DistinctionSummaryV30Rc1
from orcid_api_v3.models.distinction_summary_v30_rc2 import DistinctionSummaryV30Rc2
from orcid_api_v3.models.distinction_v30 import DistinctionV30
from orcid_api_v3.models.distinction_v30_rc1 import DistinctionV30Rc1
from orcid_api_v3.models.distinction_v30_rc2 import DistinctionV30Rc2
from orcid_api_v3.models.distinctions_summary_v30 import DistinctionsSummaryV30
from orcid_api_v3.models.distinctions_summary_v30_rc2 import DistinctionsSummaryV30Rc2
from orcid_api_v3.models.distinctions_v30_rc1 import DistinctionsV30Rc1
from orcid_api_v3.models.education_summary_v20 import EducationSummaryV20
from orcid_api_v3.models.education_summary_v30 import EducationSummaryV30
from orcid_api_v3.models.education_summary_v30_rc1 import EducationSummaryV30Rc1
from orcid_api_v3.models.education_summary_v30_rc2 import EducationSummaryV30Rc2
from orcid_api_v3.models.education_v20 import EducationV20
from orcid_api_v3.models.education_v30 import EducationV30
from orcid_api_v3.models.education_v30_rc1 import EducationV30Rc1
from orcid_api_v3.models.education_v30_rc2 import EducationV30Rc2
from orcid_api_v3.models.educations_summary_v20 import EducationsSummaryV20
from orcid_api_v3.models.educations_summary_v30 import EducationsSummaryV30
from orcid_api_v3.models.educations_summary_v30_rc1 import EducationsSummaryV30Rc1
from orcid_api_v3.models.educations_summary_v30_rc2 import EducationsSummaryV30Rc2
from orcid_api_v3.models.email_v20 import EmailV20
from orcid_api_v3.models.email_v30 import EmailV30
from orcid_api_v3.models.email_v30_rc1 import EmailV30Rc1
from orcid_api_v3.models.email_v30_rc2 import EmailV30Rc2
from orcid_api_v3.models.emails_v20 import EmailsV20
from orcid_api_v3.models.emails_v30 import EmailsV30
from orcid_api_v3.models.emails_v30_rc1 import EmailsV30Rc1
from orcid_api_v3.models.emails_v30_rc2 import EmailsV30Rc2
from orcid_api_v3.models.employment_summary_v20 import EmploymentSummaryV20
from orcid_api_v3.models.employment_summary_v30 import EmploymentSummaryV30
from orcid_api_v3.models.employment_summary_v30_rc1 import EmploymentSummaryV30Rc1
from orcid_api_v3.models.employment_summary_v30_rc2 import EmploymentSummaryV30Rc2
from orcid_api_v3.models.employment_v20 import EmploymentV20
from orcid_api_v3.models.employment_v30 import EmploymentV30
from orcid_api_v3.models.employment_v30_rc1 import EmploymentV30Rc1
from orcid_api_v3.models.employment_v30_rc2 import EmploymentV30Rc2
from orcid_api_v3.models.employments_summary_v20 import EmploymentsSummaryV20
from orcid_api_v3.models.employments_summary_v30 import EmploymentsSummaryV30
from orcid_api_v3.models.employments_summary_v30_rc1 import EmploymentsSummaryV30Rc1
from orcid_api_v3.models.employments_summary_v30_rc2 import EmploymentsSummaryV30Rc2
from orcid_api_v3.models.external_idv20 import ExternalIDV20
from orcid_api_v3.models.external_idv30 import ExternalIDV30
from orcid_api_v3.models.external_idv30_rc1 import ExternalIDV30Rc1
from orcid_api_v3.models.external_idv30_rc2 import ExternalIDV30Rc2
from orcid_api_v3.models.external_i_ds_v20 import ExternalIDsV20
from orcid_api_v3.models.external_i_ds_v30 import ExternalIDsV30
from orcid_api_v3.models.external_i_ds_v30_rc1 import ExternalIDsV30Rc1
from orcid_api_v3.models.external_i_ds_v30_rc2 import ExternalIDsV30Rc2
from orcid_api_v3.models.family_name_v20 import FamilyNameV20
from orcid_api_v3.models.family_name_v30 import FamilyNameV30
from orcid_api_v3.models.family_name_v30_rc1 import FamilyNameV30Rc1
from orcid_api_v3.models.family_name_v30_rc2 import FamilyNameV30Rc2
from orcid_api_v3.models.funding_contributor_attributes_v20 import FundingContributorAttributesV20
from orcid_api_v3.models.funding_contributor_attributes_v30 import FundingContributorAttributesV30
from orcid_api_v3.models.funding_contributor_attributes_v30_rc1 import FundingContributorAttributesV30Rc1
from orcid_api_v3.models.funding_contributor_attributes_v30_rc2 import FundingContributorAttributesV30Rc2
from orcid_api_v3.models.funding_contributor_v20 import FundingContributorV20
from orcid_api_v3.models.funding_contributor_v30 import FundingContributorV30
from orcid_api_v3.models.funding_contributor_v30_rc1 import FundingContributorV30Rc1
from orcid_api_v3.models.funding_contributor_v30_rc2 import FundingContributorV30Rc2
from orcid_api_v3.models.funding_contributors_v20 import FundingContributorsV20
from orcid_api_v3.models.funding_contributors_v30 import FundingContributorsV30
from orcid_api_v3.models.funding_contributors_v30_rc1 import FundingContributorsV30Rc1
from orcid_api_v3.models.funding_contributors_v30_rc2 import FundingContributorsV30Rc2
from orcid_api_v3.models.funding_group_v20 import FundingGroupV20
from orcid_api_v3.models.funding_group_v30 import FundingGroupV30
from orcid_api_v3.models.funding_group_v30_rc1 import FundingGroupV30Rc1
from orcid_api_v3.models.funding_group_v30_rc2 import FundingGroupV30Rc2
from orcid_api_v3.models.funding_summary_v20 import FundingSummaryV20
from orcid_api_v3.models.funding_summary_v30 import FundingSummaryV30
from orcid_api_v3.models.funding_summary_v30_rc1 import FundingSummaryV30Rc1
from orcid_api_v3.models.funding_summary_v30_rc2 import FundingSummaryV30Rc2
from orcid_api_v3.models.funding_title_v20 import FundingTitleV20
from orcid_api_v3.models.funding_title_v30 import FundingTitleV30
from orcid_api_v3.models.funding_title_v30_rc1 import FundingTitleV30Rc1
from orcid_api_v3.models.funding_title_v30_rc2 import FundingTitleV30Rc2
from orcid_api_v3.models.funding_v20 import FundingV20
from orcid_api_v3.models.funding_v30 import FundingV30
from orcid_api_v3.models.funding_v30_rc1 import FundingV30Rc1
from orcid_api_v3.models.funding_v30_rc2 import FundingV30Rc2
from orcid_api_v3.models.fundings_v20 import FundingsV20
from orcid_api_v3.models.fundings_v30 import FundingsV30
from orcid_api_v3.models.fundings_v30_rc1 import FundingsV30Rc1
from orcid_api_v3.models.fundings_v30_rc2 import FundingsV30Rc2
from orcid_api_v3.models.fuzzy_date_v20 import FuzzyDateV20
from orcid_api_v3.models.fuzzy_date_v30 import FuzzyDateV30
from orcid_api_v3.models.fuzzy_date_v30_rc1 import FuzzyDateV30Rc1
from orcid_api_v3.models.fuzzy_date_v30_rc2 import FuzzyDateV30Rc2
from orcid_api_v3.models.given_names_v20 import GivenNamesV20
from orcid_api_v3.models.given_names_v30 import GivenNamesV30
from orcid_api_v3.models.given_names_v30_rc1 import GivenNamesV30Rc1
from orcid_api_v3.models.given_names_v30_rc2 import GivenNamesV30Rc2
from orcid_api_v3.models.group_id_record import GroupIdRecord
from orcid_api_v3.models.group_id_records import GroupIdRecords
from orcid_api_v3.models.history_v20 import HistoryV20
from orcid_api_v3.models.history_v30 import HistoryV30
from orcid_api_v3.models.history_v30_rc1 import HistoryV30Rc1
from orcid_api_v3.models.history_v30_rc2 import HistoryV30Rc2
from orcid_api_v3.models.invited_position_summary_v30 import InvitedPositionSummaryV30
from orcid_api_v3.models.invited_position_summary_v30_rc1 import InvitedPositionSummaryV30Rc1
from orcid_api_v3.models.invited_position_summary_v30_rc2 import InvitedPositionSummaryV30Rc2
from orcid_api_v3.models.invited_position_v30 import InvitedPositionV30
from orcid_api_v3.models.invited_position_v30_rc1 import InvitedPositionV30Rc1
from orcid_api_v3.models.invited_position_v30_rc2 import InvitedPositionV30Rc2
from orcid_api_v3.models.invited_positions_v30 import InvitedPositionsV30
from orcid_api_v3.models.invited_positions_v30_rc1 import InvitedPositionsV30Rc1
from orcid_api_v3.models.invited_positions_v30_rc2 import InvitedPositionsV30Rc2
from orcid_api_v3.models.item_v20 import ItemV20
from orcid_api_v3.models.item_v30 import ItemV30
from orcid_api_v3.models.item_v30_rc1 import ItemV30Rc1
from orcid_api_v3.models.item_v30_rc2 import ItemV30Rc2
from orcid_api_v3.models.items_v20 import ItemsV20
from orcid_api_v3.models.items_v30 import ItemsV30
from orcid_api_v3.models.items_v30_rc1 import ItemsV30Rc1
from orcid_api_v3.models.items_v30_rc2 import ItemsV30Rc2
from orcid_api_v3.models.keyword_v20 import KeywordV20
from orcid_api_v3.models.keyword_v30 import KeywordV30
from orcid_api_v3.models.keyword_v30_rc1 import KeywordV30Rc1
from orcid_api_v3.models.keyword_v30_rc2 import KeywordV30Rc2
from orcid_api_v3.models.keywords_v20 import KeywordsV20
from orcid_api_v3.models.keywords_v30 import KeywordsV30
from orcid_api_v3.models.keywords_v30_rc1 import KeywordsV30Rc1
from orcid_api_v3.models.keywords_v30_rc2 import KeywordsV30Rc2
from orcid_api_v3.models.last_modified_date_v20 import LastModifiedDateV20
from orcid_api_v3.models.last_modified_date_v30 import LastModifiedDateV30
from orcid_api_v3.models.last_modified_date_v30_rc1 import LastModifiedDateV30Rc1
from orcid_api_v3.models.last_modified_date_v30_rc2 import LastModifiedDateV30Rc2
from orcid_api_v3.models.membership_summary_v30 import MembershipSummaryV30
from orcid_api_v3.models.membership_summary_v30_rc1 import MembershipSummaryV30Rc1
from orcid_api_v3.models.membership_summary_v30_rc2 import MembershipSummaryV30Rc2
from orcid_api_v3.models.membership_v30 import MembershipV30
from orcid_api_v3.models.membership_v30_rc1 import MembershipV30Rc1
from orcid_api_v3.models.membership_v30_rc2 import MembershipV30Rc2
from orcid_api_v3.models.memberships_v30 import MembershipsV30
from orcid_api_v3.models.memberships_v30_rc1 import MembershipsV30Rc1
from orcid_api_v3.models.memberships_v30_rc2 import MembershipsV30Rc2
from orcid_api_v3.models.month_v20 import MonthV20
from orcid_api_v3.models.month_v30 import MonthV30
from orcid_api_v3.models.month_v30_rc1 import MonthV30Rc1
from orcid_api_v3.models.month_v30_rc2 import MonthV30Rc2
from orcid_api_v3.models.name_v20 import NameV20
from orcid_api_v3.models.name_v30 import NameV30
from orcid_api_v3.models.name_v30_rc1 import NameV30Rc1
from orcid_api_v3.models.name_v30_rc2 import NameV30Rc2
from orcid_api_v3.models.notification import Notification
from orcid_api_v3.models.notification_permission_v20 import NotificationPermissionV20
from orcid_api_v3.models.notification_permission_v30 import NotificationPermissionV30
from orcid_api_v3.models.notification_permission_v30_rc1 import NotificationPermissionV30Rc1
from orcid_api_v3.models.notification_permission_v30_rc2 import NotificationPermissionV30Rc2
from orcid_api_v3.models.orcid_identifier_v20 import OrcidIdentifierV20
from orcid_api_v3.models.orcid_identifier_v30 import OrcidIdentifierV30
from orcid_api_v3.models.orcid_identifier_v30_rc1 import OrcidIdentifierV30Rc1
from orcid_api_v3.models.orcid_identifier_v30_rc2 import OrcidIdentifierV30Rc2
from orcid_api_v3.models.organization_address_v20 import OrganizationAddressV20
from orcid_api_v3.models.organization_address_v30 import OrganizationAddressV30
from orcid_api_v3.models.organization_address_v30_rc1 import OrganizationAddressV30Rc1
from orcid_api_v3.models.organization_address_v30_rc2 import OrganizationAddressV30Rc2
from orcid_api_v3.models.organization_defined_funding_sub_type_v20 import OrganizationDefinedFundingSubTypeV20
from orcid_api_v3.models.organization_defined_funding_sub_type_v30 import OrganizationDefinedFundingSubTypeV30
from orcid_api_v3.models.organization_defined_funding_sub_type_v30_rc1 import OrganizationDefinedFundingSubTypeV30Rc1
from orcid_api_v3.models.organization_defined_funding_sub_type_v30_rc2 import OrganizationDefinedFundingSubTypeV30Rc2
from orcid_api_v3.models.organization_v20 import OrganizationV20
from orcid_api_v3.models.organization_v30 import OrganizationV30
from orcid_api_v3.models.organization_v30_rc1 import OrganizationV30Rc1
from orcid_api_v3.models.organization_v30_rc2 import OrganizationV30Rc2
from orcid_api_v3.models.other_name_v20 import OtherNameV20
from orcid_api_v3.models.other_name_v30 import OtherNameV30
from orcid_api_v3.models.other_name_v30_rc1 import OtherNameV30Rc1
from orcid_api_v3.models.other_name_v30_rc2 import OtherNameV30Rc2
from orcid_api_v3.models.other_names_v20 import OtherNamesV20
from orcid_api_v3.models.other_names_v30 import OtherNamesV30
from orcid_api_v3.models.other_names_v30_rc1 import OtherNamesV30Rc1
from orcid_api_v3.models.other_names_v30_rc2 import OtherNamesV30Rc2
from orcid_api_v3.models.peer_review_duplicate_group_v30 import PeerReviewDuplicateGroupV30
from orcid_api_v3.models.peer_review_duplicate_group_v30_rc1 import PeerReviewDuplicateGroupV30Rc1
from orcid_api_v3.models.peer_review_duplicate_group_v30_rc2 import PeerReviewDuplicateGroupV30Rc2
from orcid_api_v3.models.peer_review_group_v20 import PeerReviewGroupV20
from orcid_api_v3.models.peer_review_group_v30 import PeerReviewGroupV30
from orcid_api_v3.models.peer_review_group_v30_rc1 import PeerReviewGroupV30Rc1
from orcid_api_v3.models.peer_review_group_v30_rc2 import PeerReviewGroupV30Rc2
from orcid_api_v3.models.peer_review_summary_v20 import PeerReviewSummaryV20
from orcid_api_v3.models.peer_review_summary_v30 import PeerReviewSummaryV30
from orcid_api_v3.models.peer_review_summary_v30_rc1 import PeerReviewSummaryV30Rc1
from orcid_api_v3.models.peer_review_summary_v30_rc2 import PeerReviewSummaryV30Rc2
from orcid_api_v3.models.peer_review_v20 import PeerReviewV20
from orcid_api_v3.models.peer_review_v30 import PeerReviewV30
from orcid_api_v3.models.peer_review_v30_rc1 import PeerReviewV30Rc1
from orcid_api_v3.models.peer_review_v30_rc2 import PeerReviewV30Rc2
from orcid_api_v3.models.peer_reviews_v20 import PeerReviewsV20
from orcid_api_v3.models.peer_reviews_v30 import PeerReviewsV30
from orcid_api_v3.models.peer_reviews_v30_rc1 import PeerReviewsV30Rc1
from orcid_api_v3.models.peer_reviews_v30_rc2 import PeerReviewsV30Rc2
from orcid_api_v3.models.person_external_identifier_v20 import PersonExternalIdentifierV20
from orcid_api_v3.models.person_external_identifier_v30 import PersonExternalIdentifierV30
from orcid_api_v3.models.person_external_identifier_v30_rc1 import PersonExternalIdentifierV30Rc1
from orcid_api_v3.models.person_external_identifier_v30_rc2 import PersonExternalIdentifierV30Rc2
from orcid_api_v3.models.person_external_identifiers_v20 import PersonExternalIdentifiersV20
from orcid_api_v3.models.person_external_identifiers_v30 import PersonExternalIdentifiersV30
from orcid_api_v3.models.person_external_identifiers_v30_rc1 import PersonExternalIdentifiersV30Rc1
from orcid_api_v3.models.person_external_identifiers_v30_rc2 import PersonExternalIdentifiersV30Rc2
from orcid_api_v3.models.person_v20 import PersonV20
from orcid_api_v3.models.person_v30 import PersonV30
from orcid_api_v3.models.person_v30_rc1 import PersonV30Rc1
from orcid_api_v3.models.person_v30_rc2 import PersonV30Rc2
from orcid_api_v3.models.personal_details_v20 import PersonalDetailsV20
from orcid_api_v3.models.personal_details_v30 import PersonalDetailsV30
from orcid_api_v3.models.personal_details_v30_rc1 import PersonalDetailsV30Rc1
from orcid_api_v3.models.personal_details_v30_rc2 import PersonalDetailsV30Rc2
from orcid_api_v3.models.preferences_v20 import PreferencesV20
from orcid_api_v3.models.preferences_v30 import PreferencesV30
from orcid_api_v3.models.preferences_v30_rc1 import PreferencesV30Rc1
from orcid_api_v3.models.preferences_v30_rc2 import PreferencesV30Rc2
from orcid_api_v3.models.publication_date_v20 import PublicationDateV20
from orcid_api_v3.models.publication_date_v30 import PublicationDateV30
from orcid_api_v3.models.publication_date_v30_rc1 import PublicationDateV30Rc1
from orcid_api_v3.models.publication_date_v30_rc2 import PublicationDateV30Rc2
from orcid_api_v3.models.qualification_summary_v30 import QualificationSummaryV30
from orcid_api_v3.models.qualification_summary_v30_rc1 import QualificationSummaryV30Rc1
from orcid_api_v3.models.qualification_summary_v30_rc2 import QualificationSummaryV30Rc2
from orcid_api_v3.models.qualification_v30 import QualificationV30
from orcid_api_v3.models.qualification_v30_rc1 import QualificationV30Rc1
from orcid_api_v3.models.qualification_v30_rc2 import QualificationV30Rc2
from orcid_api_v3.models.qualifications_v30 import QualificationsV30
from orcid_api_v3.models.qualifications_v30_rc1 import QualificationsV30Rc1
from orcid_api_v3.models.qualifications_v30_rc2 import QualificationsV30Rc2
from orcid_api_v3.models.record_v20 import RecordV20
from orcid_api_v3.models.record_v30 import RecordV30
from orcid_api_v3.models.record_v30_rc1 import RecordV30Rc1
from orcid_api_v3.models.record_v30_rc2 import RecordV30Rc2
from orcid_api_v3.models.research_resource_group_v30 import ResearchResourceGroupV30
from orcid_api_v3.models.research_resource_group_v30_rc1 import ResearchResourceGroupV30Rc1
from orcid_api_v3.models.research_resource_group_v30_rc2 import ResearchResourceGroupV30Rc2
from orcid_api_v3.models.research_resource_hosts_v30 import ResearchResourceHostsV30
from orcid_api_v3.models.research_resource_hosts_v30_rc1 import ResearchResourceHostsV30Rc1
from orcid_api_v3.models.research_resource_hosts_v30_rc2 import ResearchResourceHostsV30Rc2
from orcid_api_v3.models.research_resource_item_v30 import ResearchResourceItemV30
from orcid_api_v3.models.research_resource_item_v30_rc1 import ResearchResourceItemV30Rc1
from orcid_api_v3.models.research_resource_item_v30_rc2 import ResearchResourceItemV30Rc2
from orcid_api_v3.models.research_resource_proposal_v30 import ResearchResourceProposalV30
from orcid_api_v3.models.research_resource_proposal_v30_rc1 import ResearchResourceProposalV30Rc1
from orcid_api_v3.models.research_resource_proposal_v30_rc2 import ResearchResourceProposalV30Rc2
from orcid_api_v3.models.research_resource_summary_v30 import ResearchResourceSummaryV30
from orcid_api_v3.models.research_resource_summary_v30_rc1 import ResearchResourceSummaryV30Rc1
from orcid_api_v3.models.research_resource_summary_v30_rc2 import ResearchResourceSummaryV30Rc2
from orcid_api_v3.models.research_resource_title_v30 import ResearchResourceTitleV30
from orcid_api_v3.models.research_resource_title_v30_rc1 import ResearchResourceTitleV30Rc1
from orcid_api_v3.models.research_resource_title_v30_rc2 import ResearchResourceTitleV30Rc2
from orcid_api_v3.models.research_resource_v30 import ResearchResourceV30
from orcid_api_v3.models.research_resource_v30_rc1 import ResearchResourceV30Rc1
from orcid_api_v3.models.research_resource_v30_rc2 import ResearchResourceV30Rc2
from orcid_api_v3.models.research_resources_v30 import ResearchResourcesV30
from orcid_api_v3.models.research_resources_v30_rc1 import ResearchResourcesV30Rc1
from orcid_api_v3.models.research_resources_v30_rc2 import ResearchResourcesV30Rc2
from orcid_api_v3.models.researcher_url_v20 import ResearcherUrlV20
from orcid_api_v3.models.researcher_url_v30 import ResearcherUrlV30
from orcid_api_v3.models.researcher_url_v30_rc1 import ResearcherUrlV30Rc1
from orcid_api_v3.models.researcher_url_v30_rc2 import ResearcherUrlV30Rc2
from orcid_api_v3.models.researcher_urls_v20 import ResearcherUrlsV20
from orcid_api_v3.models.researcher_urls_v30 import ResearcherUrlsV30
from orcid_api_v3.models.researcher_urls_v30_rc1 import ResearcherUrlsV30Rc1
from orcid_api_v3.models.researcher_urls_v30_rc2 import ResearcherUrlsV30Rc2
from orcid_api_v3.models.result_v20 import ResultV20
from orcid_api_v3.models.result_v30 import ResultV30
from orcid_api_v3.models.result_v30_rc1 import ResultV30Rc1
from orcid_api_v3.models.result_v30_rc2 import ResultV30Rc2
from orcid_api_v3.models.search_v20 import SearchV20
from orcid_api_v3.models.search_v30 import SearchV30
from orcid_api_v3.models.search_v30_rc1 import SearchV30Rc1
from orcid_api_v3.models.search_v30_rc2 import SearchV30Rc2
from orcid_api_v3.models.service_summary_v30 import ServiceSummaryV30
from orcid_api_v3.models.service_summary_v30_rc1 import ServiceSummaryV30Rc1
from orcid_api_v3.models.service_summary_v30_rc2 import ServiceSummaryV30Rc2
from orcid_api_v3.models.service_v30 import ServiceV30
from orcid_api_v3.models.service_v30_rc1 import ServiceV30Rc1
from orcid_api_v3.models.service_v30_rc2 import ServiceV30Rc2
from orcid_api_v3.models.services_v30 import ServicesV30
from orcid_api_v3.models.services_v30_rc1 import ServicesV30Rc1
from orcid_api_v3.models.services_v30_rc2 import ServicesV30Rc2
from orcid_api_v3.models.source_client_id_v20 import SourceClientIdV20
from orcid_api_v3.models.source_client_id_v30 import SourceClientIdV30
from orcid_api_v3.models.source_client_id_v30_rc1 import SourceClientIdV30Rc1
from orcid_api_v3.models.source_client_id_v30_rc2 import SourceClientIdV30Rc2
from orcid_api_v3.models.source_name_v20 import SourceNameV20
from orcid_api_v3.models.source_name_v30 import SourceNameV30
from orcid_api_v3.models.source_name_v30_rc1 import SourceNameV30Rc1
from orcid_api_v3.models.source_name_v30_rc2 import SourceNameV30Rc2
from orcid_api_v3.models.source_orcid_v20 import SourceOrcidV20
from orcid_api_v3.models.source_orcid_v30 import SourceOrcidV30
from orcid_api_v3.models.source_orcid_v30_rc1 import SourceOrcidV30Rc1
from orcid_api_v3.models.source_orcid_v30_rc2 import SourceOrcidV30Rc2
from orcid_api_v3.models.source_v20 import SourceV20
from orcid_api_v3.models.source_v30 import SourceV30
from orcid_api_v3.models.source_v30_rc1 import SourceV30Rc1
from orcid_api_v3.models.source_v30_rc2 import SourceV30Rc2
from orcid_api_v3.models.subject_name_v30 import SubjectNameV30
from orcid_api_v3.models.subject_name_v30_rc2 import SubjectNameV30Rc2
from orcid_api_v3.models.submission_date_v20 import SubmissionDateV20
from orcid_api_v3.models.submission_date_v30 import SubmissionDateV30
from orcid_api_v3.models.submission_date_v30_rc1 import SubmissionDateV30Rc1
from orcid_api_v3.models.submission_date_v30_rc2 import SubmissionDateV30Rc2
from orcid_api_v3.models.subtitle_v20 import SubtitleV20
from orcid_api_v3.models.subtitle_v30 import SubtitleV30
from orcid_api_v3.models.subtitle_v30_rc1 import SubtitleV30Rc1
from orcid_api_v3.models.subtitle_v30_rc2 import SubtitleV30Rc2
from orcid_api_v3.models.title_v20 import TitleV20
from orcid_api_v3.models.title_v30 import TitleV30
from orcid_api_v3.models.title_v30_rc1 import TitleV30Rc1
from orcid_api_v3.models.title_v30_rc2 import TitleV30Rc2
from orcid_api_v3.models.transient_error import TransientError
from orcid_api_v3.models.transient_non_empty_string import TransientNonEmptyString
from orcid_api_v3.models.translated_title_v20 import TranslatedTitleV20
from orcid_api_v3.models.translated_title_v30 import TranslatedTitleV30
from orcid_api_v3.models.translated_title_v30_rc1 import TranslatedTitleV30Rc1
from orcid_api_v3.models.translated_title_v30_rc2 import TranslatedTitleV30Rc2
from orcid_api_v3.models.url_v20 import UrlV20
from orcid_api_v3.models.url_v30 import UrlV30
from orcid_api_v3.models.url_v30_rc1 import UrlV30Rc1
from orcid_api_v3.models.url_v30_rc2 import UrlV30Rc2
from orcid_api_v3.models.work_bulk_v20 import WorkBulkV20
from orcid_api_v3.models.work_bulk_v30 import WorkBulkV30
from orcid_api_v3.models.work_bulk_v30_rc1 import WorkBulkV30Rc1
from orcid_api_v3.models.work_bulk_v30_rc2 import WorkBulkV30Rc2
from orcid_api_v3.models.work_contributors_v20 import WorkContributorsV20
from orcid_api_v3.models.work_contributors_v30 import WorkContributorsV30
from orcid_api_v3.models.work_contributors_v30_rc1 import WorkContributorsV30Rc1
from orcid_api_v3.models.work_contributors_v30_rc2 import WorkContributorsV30Rc2
from orcid_api_v3.models.work_group_v20 import WorkGroupV20
from orcid_api_v3.models.work_group_v30 import WorkGroupV30
from orcid_api_v3.models.work_group_v30_rc1 import WorkGroupV30Rc1
from orcid_api_v3.models.work_group_v30_rc2 import WorkGroupV30Rc2
from orcid_api_v3.models.work_summary_v20 import WorkSummaryV20
from orcid_api_v3.models.work_summary_v30 import WorkSummaryV30
from orcid_api_v3.models.work_summary_v30_rc1 import WorkSummaryV30Rc1
from orcid_api_v3.models.work_summary_v30_rc2 import WorkSummaryV30Rc2
from orcid_api_v3.models.work_title_v20 import WorkTitleV20
from orcid_api_v3.models.work_title_v30 import WorkTitleV30
from orcid_api_v3.models.work_title_v30_rc1 import WorkTitleV30Rc1
from orcid_api_v3.models.work_title_v30_rc2 import WorkTitleV30Rc2
from orcid_api_v3.models.work_v20 import WorkV20
from orcid_api_v3.models.work_v30 import WorkV30
from orcid_api_v3.models.work_v30_rc1 import WorkV30Rc1
from orcid_api_v3.models.work_v30_rc2 import WorkV30Rc2
from orcid_api_v3.models.works_summary_v20 import WorksSummaryV20
from orcid_api_v3.models.works_summary_v30 import WorksSummaryV30
from orcid_api_v3.models.works_summary_v30_rc1 import WorksSummaryV30Rc1
from orcid_api_v3.models.works_summary_v30_rc2 import WorksSummaryV30Rc2
from orcid_api_v3.models.year_v20 import YearV20
from orcid_api_v3.models.year_v30 import YearV30
from orcid_api_v3.models.year_v30_rc1 import YearV30Rc1
from orcid_api_v3.models.year_v30_rc2 import YearV30Rc2
