{% extends "layout.html" %}
{% block content %}
  <h1>{{title}}</h1>
  <table class="table table-hover table-bordered">
    <tbody>
      <tr>
        <td>
          <strong>Total sent invitations</strong>
        </td>
        <td>
          {{summary.total}}
        </td>
      </tr>
      <tr>
        <td>
          <strong>Total confirmed invitations</strong>
        </td>
        <td>
          {{summary.confirmed}}
        </td>
      </tr>
      <tr>
        <td>
          <strong>Total unconfirmed invitations</strong>
        </td>
        <td>
          {{summary.total - summary.confirmed}}
        </td>
      </tr>
    </tbody>
  </table>
  <h3>Unconfirmed invitations</h3>
  <table class="table table-striped table-bordered table-hover model-list">
    <thead>
      <tr>
        <th class="column-header">
          Sent
        </th>
        <th class="column-header">
          Organisation
        </th>
        <th class="column-header">
          Email
        </th>
      </tr>
    </thead>
    <tbody>
      {%- for ui in unconfirmed_invitations %}
      <tr>
        <td class="col-name">{{ui.created_at | isodate }}</td>
        <td class="col-name">{{ui.org.name}}</td>
        <td class="col-name">{{ui.email}}</td>
      </tr>
    {% endfor %}
    </tbody>
  </table>
{% endblock %}
